How to contribute — ASE documentation

### Navigation

- index
- modules |
- ASE development »

# How to contribute

Discussion of ASE development takes place on the ase-developer mailing list and on the #ase IRC channel on freenode.

We welcome new developers who would like to help work on improving ASE. If you would like to contribute, your should first tell us what you want to work on. Use the mailing list for that.

## SVN access

We don’t give new contributers write access to our SVN repository from day one. So, you will have to create a patch and send it to the mailing list:

    $ svn checkout https://svn.fysik.dtu.dk/projects/ase/trunk myase
    $ cd myase
    $ # do your thing ...
    $ svn diff > patch.txt

Become inspired by the modern software development methods: https://www.youtube.com/watch?v=_I94-tJlovg https://www.youtube.com/watch?v=IBghnXBz3_w and how they apply to computational science in ASE: https://www.youtube.com/watch?v=WKoImDmYFQE https://www.youtube.com/watch?v=1-dUkyn_fZA

Before you send the patch, please read our Coding Conventions and learn how to use pep8.py, pylint and epydoc:

- Run pep8.py on your code
- Using pylint to check your code
- Run epydoc on your code

One of the current committers will look at the patch and give you some feedback. Maybe the patch is fine and the committer will commit it to trunk. There could also be some more work to do like:

- make it compatible with all supported pythons (see Installation guide).
- write more comments
- fix docstrings
- write a test
- add some documentation

Once everyone is happy, the patch can be applied. This patch-feedback loop is not something we have invented to prevent you from contributing - it should be viewed as an opportunity for you to learn how to write code that fits into the ASE codebase.

After a couple of contributions, we will probably trust you enough to add you as a committer.

## Committers

Here is the list of current committers:

real name | user name | email
--- | --- | ---
Andrew Peterson | anpet | andrew_peterson:brown,edu
Ask Hjorth Larsen | askhl | asklarsen:gmail,com
Christopher Patrick | chripa | chripa:fysik,dtu,dk
Elvar Örn Jónsson | eojons | elvar,jonsson:fysik,dtu,dk
Eric Hermes | ehermes | ehermes:chem,wisc,edu
Filip Anselm Rasmussen | fras | fras:fysik,dtu,dk
Gaël Donval | gdonval | gael,donval:cnrs-imn,fr
George Tritsaris | getri | gtritsaris:seas,harvard,edu
Glen Jenness | gjenness | glenjenness:gmail,com
Heine Anton Hansen | hahansen | hahansen:fysik,dtu,dk
Ivano Eligio Castelli | ivca | ivca:fysik,dtu,dk
Jakob Blomquist | jakobb | jakobb:fysik,dtu,dk
Jakob Schiotz | schiotz | schiotz:fysik,dtu,dk
James Kermode | kermode | james,kermode:gmail,com
Janne Blomqvist | jblomqvist | Janne,Blomqvist:tkk,fi
Jens Jørgen Mortensen | jensj | jensj:fysik,dtu,dk
Jesper Friis | jesperf | jesper,friis:sintef,no
Jesper Kleis | kleis | kleis:fysik,dtu,dk
Jess Wellendorff Pedersen | jesswe | jesswe:fysik,dtu,dk
Jingzhe Chen | jingzhe | jingzhe:fysik,dtu,dk
John Kitchin | jkitchin | jkitchin:andrew,cmu,edu
Jonas Bjork | bjork | jonbj:ifm,liu,se
Jon Bergmann Maronsson | jber | jber:fysik,dtu,dk
Jussi Enkovaara | jussie | jussi,enkovaara:csc,fi
Karsten Wedel Jacobsen | kwj | kwj:fysik,dtu,dk
Kristen Kaasbjerg | kkaa | kkaa:fysik,dtu,dk
Kristian Baruël Ørnsø | krbt | krbt:fysik,dtu,dk
Lars Grabow | grabow | grabow:uh,edu
Lars Pastewka | pastewka | lars,pastewka:iwm,fraunhofer,de
Lasse Vilhelmsen | lassebv | lassebv:phys,au,dk
Marcin Dulak | dulak | dulak:fysik,dtu,dk
Marco Vanin | mvanin | mvanin:fysik,dtu,dk
Markus Kaukonen | markus | markus,kaukonen:iki,fi
Martin Hangaard Hansen | mhah | mhah:fysik,dtu,dk
Mattias Slabanja | slabanja | slabanja:chalmers,se
Michael Walter | miwalter | Michael,Walter:fmf,uni-freiburg,de
Mikkel Strange | strange | mikkel,strange:gmail,com
Mohnish Pandey | mohpa | mohpa:fysik,dtu,dk
Morten Niklas Gjerding | mogje | mogje:fysik,dtu,dk
Poul Georg Moses | moses | poulgeorgmoses:gmail,com
Rolf Würdemann | rowue | rowue:digitalis,org
Steen Lysgaard | stly | stly:fysik,dtu,dk
Stephan Schenk | schenkst | stephan,schenk:basf,com
Tao Jiang | tjiang | tjiang:fysik,dtu,dk
Thomas Olsen | tolsen | tolsen:fysik,dtu,dk
Tristan Maxson | tgmaxson | tgmaxson:gmail,com

### Navigation

- index
- modules |
- ASE development »